pyawair Python Wrapper for uhooair.com Air Quality Sensors
=======================

[![Build Status](https://travis-ci.com/netmanchris/pyuhooair.svg?branch=master)](https://travis-ci.com/netmanchris/pyuhooair)
[![Coverage Status](https://coveralls.io/repos/github/netmanchris/pyuhooair/badge.svg?branch=master)](https://coveralls.io/github/netmanchris/pyuhooair?branch=master)

This project is offered under and Apache2 license and is not supported officialy by uHoo.

For more information, please visit the project home page at `GITHub.com <https://github
.com/netmanchris/pyuhooair`.


What's Changed:

0.0.1  Initial Posting to Pypi. Basic functionality and scaffolding. Lots of work to do.
